@@ -457,6 +457,7 @@ namespace diskCache
           const std::string& Caller,
           const std::string& JobInfo ) const
     {
+      std::cerr << "DEBUG: Starting Directory::Scan" << std::endl;
       static const CHAR* const caller( "diskCache::Cache::Directory::Scan( ): " );
 
       dirref_type       retval;
@@ -470,6 +471,7 @@ namespace diskCache
         //---------------------------------------------------------------
         StatInfo          stat_info;
 
+        std::cerr << "DEBUG: do_stat 1: fullname: " << fullname << std::endl;
         stat_info.mod_time = do_stat( fullname, stat_info.stat_buffer, IsRoot( )  );
         QUEUE_LOG_MESSAGE( "Directory::Scan: " << Fullname( )
                            << " modified: " << ( is_updated( m_last_time_modified,
@@ -505,6 +507,7 @@ namespace diskCache
           //-------------------------------------------------------------
           MutexLock       lock( m_scan_baton, __FILE__, __LINE__ );
 
+          std::cerr << "DEBUG: do_stat 2: fullname: " << fullname << std::endl;
           stat_info.mod_time = do_stat( fullname,
                                         stat_info.stat_buffer, IsRoot( ) );
           if ( is_updated( m_last_time_modified,
@@ -606,6 +609,7 @@ namespace diskCache
         }
         throw; /* Rethrow the exception */
       }
+      std::cerr << "DEBUG: Ending Directory::Scan" << std::endl;
       return retval;
     } // method Directory::Scan( ScanResults& Results )
 
@@ -840,6 +844,7 @@ namespace
   {
     static const CHAR* const method_name( __FILE__ "::anonymous::do_stat: " );
 
+    std::cerr << "DEBUG: do_stat: Path: " << Path << std::endl;
     QUEUE_LOG_MESSAGE( "Entry: " << Path
                        ,
                        MT_DEBUG,
@@ -983,7 +988,7 @@ namespace
     //-------------------------------------------------------------------
     // Collect all entries for the directory.
     //-------------------------------------------------------------------
-    typedef LDASTools::AL::Directory::block_read_type         entries_type;
+    typedef LDASTools::AL::Directory::block_read_type   entries_type;
     entries_type                                        entries;
     
     {
@@ -1029,6 +1034,17 @@ namespace
       }
       catch( const TimeoutException& Exception )
       {
+        try {
+          //--------------------------------------------------------------
+          // Close
+          //--------------------------------------------------------------
+          active_func = close_func;
+          current_dir.Close( );
+        }
+        catch( ... )
+        {
+        }
+
         std::ostringstream   msg;
 
         msg << "TimeoutException for: " << current_dir.Name( )
@@ -1117,6 +1133,11 @@ namespace
             temp_file += *entry_cur;
           
             struct stat stat_struct;
+            std::cerr << "DEBUG: do_stat:"
+                      << " Path: " << Path
+                      << " entry_cur: " << *entry_cur
+                      << " temp_file: " << temp_file
+                      << std::endl;
             do_stat( temp_file, stat_struct, false );
 
             if ( S_ISLNK( stat_struct.st_mode ) )
