@@ -114,10 +114,12 @@ namespace
       //-----------------------------------------------------------------
       directory_set_type*		m_directories;
 
+#if UNUSED
       //-----------------------------------------------------------------
       /// \brief Default Constructor
      //-----------------------------------------------------------------
       info( );
+#endif /* UNUSED */
 
       //-----------------------------------------------------------------
       /// \brief Constructor
@@ -411,6 +413,7 @@ namespace
     }
   }
 
+#if UNUSED
   //---------------------------------------------------------------------
   /// Create a new instance of the object being careful to properly
   /// initialize data members.
@@ -419,6 +422,7 @@ namespace
   info( )
   {
   }
+#endif /* UNUSED */
 
   //---------------------------------------------------------------------
   /// Construct an instance of the object with all members of the object
