@@ -2128,9 +2128,15 @@ namespace
   }
 
 
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wunused-function"
   //---------------------------------------------------------------------
   /// \brief Search if a file exists in the cache
+  ///
+  /// \note
+  ///     Used by unit tests
   //---------------------------------------------------------------------
+
   bool ScanData::
   FindFile( const extension_type& Extension,
 	    const site_type& Site,
@@ -2174,6 +2180,7 @@ namespace
 
     return retval;
   }
+#pragma GCC diagnostic pop
 
   //---------------------------------------------------------------------
   /// 
