@@ -346,6 +346,12 @@ namespace diskCache
 			  "Name of file containing additional configuration information.",
 			  "filename" ) );
 
+      retval.Add( Option( OPT_DIRECTORY_TIMEOUT,
+			  "directory-timeout",
+			  Option::ARG_REQUIRED,
+			  "timeout for directory operations",
+			  "integer" ) );
+
       retval.Add( Option( OPT_EXCLUDED_DIRECTORIES,
 			  "excluded-directories",
 			  Option::ARG_REQUIRED,
@@ -437,6 +443,7 @@ namespace diskCache
     //-------------------------------------------------------------------
 
     const char* Daemon::VAR_NAME_CONCURRENCY = "CONCURRENCY";
+    const char* Daemon::VAR_NAME_DIRECTORY_TIMEOUT = "DIRECTORY_TIMEOUT";
     const char* Daemon::VAR_NAME_EXCLUDED_PATTERNS = "EXCLUDED_PATTERN";
     const char* Daemon::VAR_NAME_HOT_DIRECTORY_AGE =
       "HOT_DIRECTORY_AGE_SEC";
@@ -444,6 +451,7 @@ namespace diskCache
       "HOT_DIRECTORY_SCAN_INTERVAL_SEC";
     const char* Daemon::VAR_NAME_RWLOCK_INTERVAL = "RWLOCK_INTERVAL_MS";
     const char* Daemon::VAR_NAME_RWLOCK_TIMEOUT = "RWLOCK_TIMEOUT_MS";
+    const char* Daemon::VAR_NAME_STAT_TIMEOUT = "STAT_TIMEOUT";
 
     //-------------------------------------------------------------------
     /// Contruct a new instance of Daemon.
@@ -1186,6 +1194,12 @@ namespace diskCache
     void Daemon::
     setup_variables( int Mask )
     {
+      if ( Mask & VAR_DIRECTORY_TIMEOUT )
+      {
+	//---------------------------------------------------------------
+	//---------------------------------------------------------------
+	diskCache::Common::Variables::Set( VAR_NAME_DIRECTORY_TIMEOUT );
+      }
       if ( Mask & VAR_EXCLUDED_DIRECTORIES )
       {
 	//---------------------------------------------------------------
@@ -1252,6 +1266,14 @@ namespace diskCache
 	diskCache::Common::Variables::Set( VAR_NAME_CONCURRENCY );
       }
 
+      if ( Mask & VAR_DIRECTORY_TIMEOUT )
+      {
+	//---------------------------------------------------------------
+	// Setup directory operations timeout value
+	//---------------------------------------------------------------
+	diskCache::Common::Variables::Set( VAR_NAME_DIRECTORY_TIMEOUT );
+      }
+
       if ( Mask & VAR_HOT_DIRECTORY_AGE )
       {
 	//---------------------------------------------------------------
@@ -1296,7 +1318,7 @@ namespace diskCache
 	//---------------------------------------------------------------
 	// Setup stat timeout value
 	//---------------------------------------------------------------
-	diskCache::Common::Variables::Set( "STAT_TIMEOUT" );
+	diskCache::Common::Variables::Set( VAR_NAME_STAT_TIMEOUT );
       }
 
       //-----------------------------------------------------------------
@@ -1313,7 +1335,7 @@ namespace diskCache
       if ( Mask & VAR_CACHE_WRITE_DELAY )
       {
 	QUEUE_LOG_MESSAGE( "Setting CACHE_WRITE_DELAY: " << cache_write_delay_,
-			   MT_NOTE,
+		   MT_NOTE,
 			   0,
 			   "Daemon::setup_variables",
 			   "CXX" );
