@@ -47,6 +47,7 @@ using diskCache::MetaCommand::FilenamesRDS;
 using diskCache::MetaCommand::Intervals;
 using diskCache::MetaCommand::MountPointStats;
 using diskCache::MetaCommand::Quit;
+using diskCache::MetaCommand::Reconfigure;
 using diskCache::MetaCommand::Scan;
 using diskCache::MetaCommand::Status;
 
@@ -403,7 +404,6 @@ main( int ArgC, char** ArgV )
 	    Daemon	cmd( options, Server, cfg_filename,
 			     cache_filename.empty( ) );
 
-	    cmd.ResetOnSignal( true );
 	    cmd( );
 	  }
 	  break;
@@ -488,6 +488,16 @@ main( int ArgC, char** ArgV )
 	    cmd( );
 	  }
 	  break;
+	case CommandTable::CMD_RECONFIGURE:
+	  {
+	    //-------------------------------------------------------------
+	    // Re-read configuration file
+	    //-------------------------------------------------------------
+	    Reconfigure	cmd( options, Server );
+
+	    cmd( );
+	  }
+	  break;
 	case CommandTable::CMD_SCAN:
 	  {
 	    //-------------------------------------------------------------
