@@ -25,6 +25,10 @@ using LDASTools::AL::MutexLock;
 
 namespace
 {
+  // Directory Variables
+  void directory_timeout_reader( std::ostringstream& Value );
+  void directory_timeout_writer( const std::string& Value );
+
   // Hot Directory Variables
   void hdas_reader( std::ostringstream& Value );
   void hdas_writer( const std::string& Value );
@@ -137,6 +141,13 @@ variables_init( )
 {
   std::ostringstream dflt;
 
+  dflt.str( "" );
+  directory_timeout_reader( dflt );
+  diskCache::Common::Variables::Init( diskCache::MetaCommand::Daemon::VAR_NAME_DIRECTORY_TIMEOUT,
+				      directory_timeout_reader,
+				      directory_timeout_writer,
+				      dflt.str( ) );
+
   dflt.str( "" );
   mps_concurrency_reader( dflt );
   diskCache::Common::Variables::Init( diskCache::MetaCommand::Daemon::VAR_NAME_CONCURRENCY,
@@ -181,7 +192,7 @@ variables_init( )
 
   dflt.str( "" );
   st_reader( dflt );
-  diskCache::Common::Variables::Init( "STAT_TIMEOUT",
+  diskCache::Common::Variables::Init( diskCache::MetaCommand::Daemon::VAR_NAME_STAT_TIMEOUT,
 				      st_reader,
 				      st_writer,
 				      dflt.str( ) );
@@ -342,4 +353,26 @@ namespace
     }
   }
 
+  //---------------------------------------------------------------------
+
+  void
+  directory_timeout_reader( std::ostringstream& Value )
+  {
+    Value << LDASTools::AL::Directory::Timeout( );
+  }
+
+  void
+  directory_timeout_writer( const std::string& Value )
+  {
+    INT_4U		v;
+
+    std::istringstream	s( Value );
+
+    s >> v;
+    if ( v > 0 )
+    {
+      LDASTools::AL::Directory::Timeout( v );
+    }
+  }
+
 }
